{% extends "manage/manage_base.html" %}
{% load i18n %}

{% block help_link %}user/management/customer/reviews.html{% endblock %}
{% block section %}manage-review{% endblock %}

{% block left_slot %}
	<div id="selectable-reviews-inline">
		{{ selectable_reviews_inline|safe }}
	</div>
{% endblock %}

{% block content %}
    <div id="review-filters-inline">
        {{ review_filters_inline|safe }}
    </div>
    <div class="site-actions">
        <a class="overview"
           href="{% url lfs_manage_reviews %}">{% trans 'Overview' %}</a>

        <a class="delete delete-link"
           dialog_message="{% trans 'Do you really want to delete this review?' %}"
           href="{% url lfs_delete_review review.id %}">
           {% trans 'Delete review' %}</a>

        <form action="{% url lfs_set_review_state review.id %}"
              method="post"
              class="inline">
            <label>{% trans "Active" %}:</label>

            <select name="active">
                <option {% ifequal review.active 1 %}selected="selected"{% endifequal %}value="1">{% trans "Yes" %}</option>
                <option {% ifequal review.active 0 %}selected="selected"{% endifequal %}value="0">{% trans "No" %}</option>
            </select>

            <input class="ajax-save-button"
                   type="submit"
                   value='{% trans "Change" %}'>
        </form>
    </div>
    <div id="manage-tabs">
        <ul>
            <li class="ui-tabs-nav-item"><a href="#review">{% trans 'Review' %}</a></li>
        </ul>
        <div id="review">
            <div id="review-inline">
                {{ review_inline|safe }}
            </div>
        </div>
    </div>
{% endblock %}
