{% load i18n %}
{% load lfs_tags %}

<form action="{% url lfs_set_cart_filters %}"
      method="post">

    <input type="hidden" name="came-from" value="cart" />
    <input type="hidden" name="cart-id" value="{{ cart.id }}" />

    <table>
        <tr>
            <td></td>
            <td class="discreet">{% trans "Start" %}</td>
            <td class="discreet">{% trans "End" %}</td>
        </tr>
        <tr>
            <td>
                <a href="{% url lfs_set_cart_filters_date %}?came-from=cart&amp;cart-id={{ cart.id }}&amp;start=0&amp;end=0"
                   class="ajax-link" title="{% trans "Today" %}">{% trans "T" %}</a>
                <a href="{% url lfs_set_cart_filters_date %}?came-from=cart&amp;cart-id={{ cart.id }}&amp;start=1&amp;end=1"
                   class="ajax-link" title="{% trans "Yesterday" %}">{% trans "Y" %}</a>
                <a href="{% url lfs_set_cart_filters_date %}?came-from=cart&amp;cart-id={{ cart.id }}&amp;start=7&amp;end=0"
                   class="ajax-link" title="{% trans "Week" %}">{% trans "W" %}</a>
            </td>
            <td>

                <input class="date-picker"
                       type="text"
                       name="start"
                       value="{{ start }}">
            </td>
            <td>

                <input class="date-picker"
                       type="text"
                       name="end"
                       value="{{ end }}">
            </td>
            <td>
                <input type="submit"
                       class="ajax-save-button" />

                <a href="{% url lfs_reset_cart_filters %}?came-from=cart&amp;cart-id={{ cart.id }}"
                   class="ajax-link reset">&nbsp;</a>
            </td>
        </tr>
    </table>
</form>
