{% extends "manage/manage_base.html" %}
{% load i18n %}

{% block help_link %}user/management/customer/carts.html{% endblock %}

{% block title %}{% trans "Manage Cart" %}{{ cart.id }}{% endblock %}
{% block section %}manage-cart{% endblock %}

{% block left_slot %}
	<div id="selectable-carts-inline">
		{{ selectable_carts_inline|safe }}
	</div>
{% endblock %}

{% block content %}
    <div id="cart-filters-inline">
        {{ cart_filters_inline|safe }}
    </div>
    <div class="site-actions">
        <a class="overview"
           href="{% url lfs_manage_carts %}">{% trans 'Overview' %}</a>
    </div>

    <div id="manage-tabs">
        <ul>
            <li class="ui-tabs-nav-item"><a href="#cart">{% trans 'Cart' %}</a></li>
        </ul>

		<div id="cart">
        	<div id="cart-inline">
        		{{ cart_inline|safe }}
        	</div>
		</div>
    </div>
{% endblock %}
