{% load i18n %}
<h2 class="navigation-title">{% trans "Categories" %}</h2>
<div class="navigation-body manage-categories-portlet">
    <ol class="manage-categories-tree sortable"
        href="{% url lfs_sort_categories %}">
        {% for category in categories %}
            <li id="category_{{ category.id }}">
                <div>
                    <a class="selectable {% if category.is_current %}selected{% endif %}"
                       href="{% url lfs_manage_category category.id %}">
                        <img class="handle" src="{{ STATIC_URL }}img/handle.png" alt="Handle" />
                        {{ category.name }}
                    </a>
                 </div>
                 {{ category.children }}

            </li>
        {% endfor %}
    </ol>
</div>
