{% load i18n %}
{% load lfs_tags %}

<form action="{% url lfs_set_customer_filters %}"
      method="post">

    <input type="hidden" name="came-from" value="customer" />
    <input type="hidden" name="customer-id" value="{{ customer.id }}" />

    <table class="filters">
        <tr>
            <td class="discreet">{% trans "Name" %}</td>
            <td></td>
        </tr>
        <tr>
            <td>
                <input type="text"
                       name="name"
                       value="{{ name }}">
            </td>
            <td>
                <input type="submit"
                       class="ajax-save-button" />

                <a href="{% url lfs_reset_customer_filters %}?came-from=customer&amp;customer-id={{ customer.id }}"
                   class="ajax-link reset">&nbsp;</a>
            </td>
        </tr>
    </table>
</form>
