{% extends "manage/manage_base.html" %}
{% load i18n %}

{% block help_link %}/user/management/shop/customer_taxes.html{% endblock %}

{% block sextion %}no-customer-taxes{% endblock %}
{% block left-slot-wrapper %}{% endblock %}

{% block content %}
    <h2>{% trans "Customer taxes" %}</h2>
    <div style="padding:10px 0 20px 0">
        {% trans "There are no customer taxes defined yet." %}
    </div>

    <div class="buttons">
        <input class="button"
               onclick="window.location='{% url lfs_add_customer_tax %}'"
               value="{% trans 'Add Customer Tax' %}">
    </div>


{% endblock %}
