{% load i18n %}
{% load lfs_tags %}

<table class="lfs-manage-table">
    <tr>
        <th colspan="2">
            {% trans 'General' %}
        </th>
    </tr>
    <tr>
        <td class="label"
            style="width:150px">
            {% trans 'ID' %}:
        </td>
        <td>
            {{ review.id }}
        </td>
    </tr>
    <tr>
        <td class="label">
            {% trans 'Active' %}:
        </td>
        <td>
            {% if review.active %}
                {% trans "Yes" %}
            {% else %}
                {% trans "No" %}
            {% endif %}
        </td>
    </tr>
    <tr>
        <td class="label">
            {% trans 'Creation date' %}:
        </td>
        <td>
            {{ review.creation_date|date:"d.m.Y - H:i" }}
        </td>
    </tr>
    <tr>
        <td class="label">
            {% trans 'Name' %}:
        </td>
        <td>
            {% if review.name %}
                {{ review.user_name }}
            {% else %}
                ---
            {% endif %}
            {% if review.user_email %}({{ review.user_email }}){% endif %}
        </td>
    </tr>
    <tr>
        <td class="label">
            {% trans 'E-Mail' %}:
        </td>
        <td>
            {% if review.user_email %}
                {{ review.user_email }}
            {% else %}
                ---
            {% endif %}
        </td>
    </tr>
    <tr>
        <td class="label">
            {% trans 'Registriert' %}:
        </td>
        <td>
            {% if review.user %}
                {% trans "Yes" %}
            {% else %}
                {% trans "No" %}
            {% endif %}
        </td>
    </tr>
    <tr>
        <td class="label">
            {% trans 'Product' %}:
        </td>
        <td>
            <a href="{{ review.content.get_absolute_url }}">
                {{ review.content.get_name }}
            </a>
        </td>
    </tr>
    <tr>
        <td class="label">
            {% trans 'Score' %}:
        </td>
        <td>
            {{ review.score }}
        </td>
    </tr>
</table>
<table class="lfs-manage-table">
    <tr>
        <th>
            {% trans 'Comment' %}:
        </th>
    </tr>
    <tr>
        <td>
            {{ review.comment|safe }}
        </td>
    </tr>
</table>
